@@ -6,5 +6,5 @@ def js_minify(js, settings: dict):
     """Minify JS main function."""
     b = Beautifier()
     opts = BeautifierOptions()
-    jsb.beautify(js, opts)
+    js = b.beautify(js, opts)
     return js, None
